@@ -13,8 +13,8 @@ import numpy as np
 #     from urllib2 import urlopen
 # For Python
 
-def readImg(image, IMG_SIZE, channels=1):
-    image_array = cv.imread(image)
+def readImg(image_path, IMG_SIZE, channels=1):
+    image_array = cv.imread(image_path)
 
     # [INFO] Using the following piece of code results in a 'None' in the training set
     # if image_array == None:
